==> foundation-ui-components-1.26.1.tgz: package/src/common/card/CardButton.tsx <==
import { Button } from '@mui/material';
import { NsButton, NsIcon } from '../';
import { NsCardButton } from './types';
import { styled } from '@nuskin/foundation-theme';

const ButtonTextVariant = styled(Button)(() => {
    return {
        padding: 0,
        borderBottom: '1px solid black',
        borderRadius: 0,
        textTransform: 'none',
        fontSize: '14px',
        fontWeight: 600,
    };
});

const CardButton = ({
    url,
    endIcon,
    buttonText,
    showButton = true,
    buttonVariant = 'outlined',
    buttonColor = 'primary',
    fullWidth = false,
    showArrowWithText = false,
}: NsCardButton) => {
    if (showButton && url) {
        return (
            <div className="cta">
                {buttonVariant === 'text' ? (
                    <ButtonTextVariant href={url}>
                        {buttonText}
                        {showArrowWithText ? (
                            <NsIcon name="arrowRight" size="small" color="primary" />
                        ) : endIcon ? (
                            <NsIcon name={endIcon} size="small" color="primary" />
                        ) : null}
                    </ButtonTextVariant>
                ) : (
                    <NsButton
                        href={url}
                        color={buttonColor}
                        variant={buttonVariant}
                        fullWidth={fullWidth}
                        endIcon={endIcon ? <NsIcon name={endIcon} color={buttonColor} /> : null}
                        className="cta-text"
                    >
                        {buttonText}
                    </NsButton>
                )}
            </div>
        );
    }
    return null;
};

export default CardButton;

==> foundation-ui-components-1.30.1.tgz: package/src/common/card/CardButton.tsx <==
import { ReactElement } from 'react';

import { Button } from '@mui/material';
import { styled } from '@nuskin/foundation-theme';

import { NsButton, NsIcon } from '../';
import { NsCardButton } from './types';

const ButtonTextVariant = styled(Button)(() => {
    return {
        padding: 0,
        borderBottom: '1px solid black',
        borderRadius: 0,
        textTransform: 'none',
        fontSize: '14px',
        fontWeight: 600,
    };
});

const CardButton = ({
    url,
    endIcon,
    buttonText,
    showButton = true,
    buttonVariant = 'outlined',
    buttonColor = 'primary',
    fullWidth = false,
    showArrowWithText = false,
}: NsCardButton): ReactElement | null => {
    if (showButton && url) {
        return (
            <div className="cta">
                {buttonVariant === 'text' ? (
                    <ButtonTextVariant href={url}>
                        {buttonText}
                        {showArrowWithText ? (
                            <NsIcon name="arrowRight" size="small" color="primary" />
                        ) : endIcon ? (
                            <NsIcon name={endIcon} size="small" color="primary" />
                        ) : null}
                    </ButtonTextVariant>
                ) : (
                    <NsButton
                        href={url}
                        color={buttonColor}
                        variant={buttonVariant}
                        fullWidth={fullWidth}
                        endIcon={endIcon ? <NsIcon name={endIcon} color={buttonColor} /> : null}
                        className="cta-text"
                    >
                        {buttonText}
                    </NsButton>
                )}
            </div>
        );
    }
    return null;
};

export default CardButton;
